import axios from '@/http';
import { parseSvg } from '@meta2d/svg';
import { cdn } from './api';

const baseurl = import.meta.env.VITE_BASEURL || '/';

export function filename(str: string) {
  const i = str.lastIndexOf('.');
  return str.substring(0, i);
}

export async function getFolders(name: string, svg?: boolean) {
  const folder = baseurl + name + '/';
  const ret = (await axios.get(folder)) as any[];

  if (!ret || !ret.map) {
    return [];
  }
  return await Promise.all(
    ret.map(async (c: any) => {
      const files = (await axios.get(folder + c.name + '/')) as any[];
      return {
        folder,
        name: globalThis.folderJson
          ? globalThis.folderJson[c.name]
            ? globalThis.folderJson[c.name]
            : c.name
          : c.name,
        pinyin: globalThis.folderJson ? c.name : null,
        show: true,
        list: [],
        count: files.length,
        svg,
      };
    })
  );
}

export async function getFiles(folder: string) {
  if (folder[folder.length - 1] !== '/') {
    folder += '/';
  }
  const files = (await axios.get(folder)) as any[];
  if (!files || !files.map) {
    return [];
  }
  return files.map((f) => {
    let fname = filename(f.name);
    return {
      name: globalThis.fileJson
        ? globalThis.fileJson[fname]
          ? globalThis.fileJson[fname]
          : fname
        : fname,
      pinyin: globalThis.fileJson ? fname : null,
      image: cdn + folder + f.name,
    };
  });
}

export async function getIcons(folder: string) {
  const files = (await axios.get(folder)) as any[];
  return await Promise.all(files.map((f) => svgToPens(f, folder)));
}

async function svgToPens(f: any, folder: string) {
  const _name = filename(f.name);
  const name = globalThis.fileJson
    ? globalThis.fileJson[_name]
      ? globalThis.fileJson[_name]
      : _name
    : _name;
  const image = cdn + folder + f.name;
  const svgDom: string = await axios.get(image);
  let _svgDom = svgDom.replace('stroke:#333;', 'stroke:#bdc7db;');
  const data = parseSvg(_svgDom);
  return {
    name,
    pinyin: globalThis.fileJson ? _name : null,
    componentDatas: data,
    svg: _svgDom,
    component: true,
  };
}
